==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/EWSPAGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EWSPAGEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EWSPAGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EWSPAGENAME"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EWSPAGEID_Type", propOrder = {
    "ewspagename",
    "description"
})
public class EWSPAGEID_Type {

    @XmlElement(name = "EWSPAGENAME", required = true)
    protected String ewspagename;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the ewspagename property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEWSPAGENAME() {
        return ewspagename;
    }

    /**
     * Sets the value of the ewspagename property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEWSPAGENAME(String value) {
        this.ewspagename = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/EWSPAGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EWSPAGEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EWSPAGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EWSPAGENAME"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EWSPAGEID_Type", propOrder = {
    "ewspagename",
    "description"
})
public class EWSPAGEID_Type {

    @XmlElement(name = "EWSPAGENAME", required = true)
    protected String ewspagename;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété ewspagename.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEWSPAGENAME() {
        return ewspagename;
    }

    /**
     * Définit la valeur de la propriété ewspagename.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEWSPAGENAME(String value) {
        this.ewspagename = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
